==> roundcubemail-1.3.1-1-any.pkg.tar.xz: usr/share/webapps/roundcubemail/program/js/tinymce/langs/nl.js <==
tinymce.addI18n('nl',{
"Cut": "Knippen",
"Heading 5": "Kop 5",
"Header 2": "Kop 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Uw browser ondersteunt geen toegang tot het clipboard. Gelieve ctrl+X\/C\/V sneltoetsen te gebruiken.",
"Heading 4": "Kop 4",
"Div": "Div",
"Heading 2": "Kop 2",
"Paste": "Plakken",
"Close": "Sluiten",
"Font Family": "Lettertype",
"Pre": "Pre",
"Align right": "Rechts uitlijnen",
"New document": "Nieuw document",
"Blockquote": "Quote",
"Numbered list": "Nummering",
"Heading 1": "Kop 1",
"Headings": "Koppen",
"Increase indent": "Inspringen vergroten",
"Formats": "Opmaak",
"Headers": "Kopteksten",
"Select all": "Alles selecteren",
"Header 3": "Kop 3",
"Blocks": "Blok",
"Undo": "Ongedaan maken",
"Strikethrough": "Doorhalen",
"Bullet list": "Opsommingsteken",
"Header 1": "Kop 1",
"Superscript": "Superscript",
"Clear formatting": "Opmaak verwijderen",
"Font Sizes": "Tekengrootte",
"Subscript": "Subscript",
"Header 6": "Kop 6",
"Redo": "Opnieuw",
"Paragraph": "Paragraaf",
"Ok": "Ok\u00e9",
"Bold": "Vet",
"Code": "Code",
"Italic": "Cursief",
"Align center": "Centreren",
"Header 5": "Kop 5",
"Heading 6": "Kop 6",
"Heading 3": "Kop 3",
"Decrease indent": "Inspringen verkleinen",
"Header 4": "Kop 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Plakken gebeurt nu als platte tekst. Tekst wordt nu ingevoegd zonder opmaak tot deze optie uitgeschakeld wordt.",
"Underline": "Onderstreept",
"Cancel": "Annuleren",
"Justify": "Uitlijnen",
"Inline": "Inlijn",
"Copy": "Kopi\u00ebren",
"Align left": "Links uitlijnen",
"Visual aids": "Hulpmiddelen",
"Lower Greek": "Griekse letters",
"Square": "Vierkant",
"Default": "Standaard",
"Lower Alpha": "Kleine letters",
"Circle": "Cirkel",
"Disc": "Bolletje",
"Upper Alpha": "Hoofdletters",
"Upper Roman": "Romeinse cijfers groot",
"Lower Roman": "Romeinse cijfers klein",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "ID moet beginnen met een letter, gevolgd door letters, nummers, streepjes, punten, dubbele punten of underscores.",
"Name": "Naam",
"Anchor": "Anker",
"Id": "ID",
"You have unsaved changes are you sure you want to navigate away?": "U hebt niet alles opgeslagen bent u zeker dat u de pagina wenst te verlaten?",
"Restore last draft": "Herstel het laatste concept",
"Special character": "Speciale karakters",
"Source code": "Broncode",
"Language": "Programmeertaal",
"Insert\/Edit code sample": "Broncode invoegen\/bewerken",
"B": "Blauw",
"R": "Rood",
"G": "Groen",
"Color": "Kleur",
"Right to left": "Rechts naar links",
"Left to right": "Links naar rechts",
"Emoticons": "Emoticons",
"Robots": "Robots",
"Document properties": "Document eigenschappen",
"Title": "Titel",
"Keywords": "Sleutelwoorden",
"Encoding": "Codering",
"Description": "Omschrijving",
"Author": "Auteur",
"Fullscreen": "Volledig scherm",
"Horizontal line": "Horizontale lijn",
"Horizontal space": "Horizontale ruimte",
"Insert\/edit image": "Afbeelding invoegen\/bewerken",
"General": "Algemeen",
"Advanced": "Geavanceerd",
"Source": "Bron",
"Border": "Rand",
"Constrain proportions": "Verhoudingen behouden",
"Vertical space": "Verticale ruimte",
"Image description": "Afbeelding omschrijving",
"Style": "Stijl",
"Dimensions": "Afmetingen",
"Insert image": "Afbeelding invoegen",
"Image": "Afbeelding",
"Zoom in": "Inzoomen",
"Contrast": "Contrast",
"Back": "Terug",
"Gamma": "Gamma",
"Flip horizontally": "Horizontaal spiegelen",
"Resize": "Formaat aanpassen",
"Sharpen": "Scherpte",
"Zoom out": "Uitzoomen",
"Image options": "Afbeelding opties",
"Apply": "Toepassen",
"Brightness": "Helderheid",
"Rotate clockwise": "Rechtsom draaien",
"Rotate counterclockwise": "Linksom draaien",
"Edit image": "Bewerk afbeelding",
"Color levels": "Kleurniveau's",
"Crop": "Uitsnijden",
"Orientation": "Orientatie",
"Flip vertically": "Verticaal spiegelen",
"Invert": "Omkeren",
"Date\/time": "Datum\/tijd",
"Insert date\/time": "Voeg datum\/tijd in",
"Remove link": "Link verwijderen",
"Url": "Url",
"Text to display": "Linktekst",
"Anchors": "Anker",
"Insert link": "Hyperlink invoegen",
"Link": "Link",
"New window": "Nieuw venster",
"None": "Geen",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "De ingegeven URL verwijst naar een extern adres. Wil je er \"http:\/\/\" aan toevoegen?",
"Paste or type a link": "Plak of typ een link",
"Target": "Doel",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "De ingegeven URL lijkt op een e-mailadres. Wil je er \"mailto:\" aan toevoegen?",
"Insert\/edit link": "Hyperlink invoegen\/bewerken",
"Insert\/edit video": "Video invoegen\/bewerken",
"Media": "Media",
"Alternative source": "Alternatieve bron",
"Paste your embed code below:": "Plak u in te sluiten code hieronder:",
"Insert video": "Video invoegen",
"Poster": "Poster",
"Insert\/edit media": "Media invoegen\/bewerken",
"Embed": "Insluiten",
"Nonbreaking space": "Vaste spatie invoegen",
"Page break": "Pagina einde",
"Paste as text": "Plakken als tekst",
"Preview": "Voorbeeld",
"Print": "Print",
"Save": "Opslaan",
"Could not find the specified string.": "Geen resultaten gevonden",
"Replace": "Vervangen",
"Next": "Volgende",
"Whole words": "Alleen hele woorden",
"Find and replace": "Zoek en vervang",
"Replace with": "Vervangen door",
"Find": "Zoeken",
"Replace all": "Alles vervangen",
"Match case": "Identieke hoofd\/kleine letters",
"Prev": "Vorige",
"Spellcheck": "Spellingscontrole",
"Finish": "Einde",
"Ignore all": "Alles negeren",
"Ignore": "Negeren",
"Add to Dictionary": "Toevoegen aan woordenlijst",
"Insert row before": "Voeg rij boven toe",
"Rows": "Rijen",
"Height": "Hoogte",
"Paste row after": "Plak rij onder",
"Alignment": "Uitlijning",
"Border color": "Randkleur",
"Column group": "Kolomgroep",
"Row": "Rij",
"Insert column before": "Voeg kolom in voor",
"Split cell": "Cel splitsen",
"Cell padding": "Ruimte binnen cel",
"Cell spacing": "Celruimte",
"Row type": "Rijtype",
"Insert table": "Tabel invoegen",
"Body": "Body",
"Caption": "Onderschrift",
"Footer": "Voettekst",
"Delete row": "Verwijder rij",
"Paste row before": "Plak rij boven",
"Scope": "Bereik",
"Delete table": "Verwijder tabel",
"H Align": "Links uitlijnen",
"Top": "Bovenaan",
"Header cell": "Kopcel",
"Column": "Kolom",
"Row group": "Rijgroep",
"Cell": "Cel",
"Middle": "Centreren",
"Cell type": "Celtype",
"Copy row": "Kopieer rij",
"Row properties": "Rij eigenschappen",
"Table properties": "Tabel eigenschappen",
"Bottom": "Onderaan",
"V Align": "Boven uitlijnen",
"Header": "Koptekst",
"Right": "Rechts",
"Insert column after": "Voeg kolom in na",
"Cols": "Kolommen",
"Insert row after": "Voeg rij onder toe",
"Width": "Breedte",
"Cell properties": "Cel eigenschappen",
"Left": "Links",
"Cut row": "Knip rij",
"Delete column": "Verwijder kolom",
"Center": "Midden",
"Merge cells": "Cellen samenvoegen",
"Insert template": "Sjabloon invoegen",
"Templates": "Sjablonen",
"Background color": "Achtergrondkleur",
"Custom...": "Eigen...",
"Custom color": "Eigen kleur",
"No color": "Geen kleur",
"Text color": "Tekstkleur",
"Table of Contents": "Inhoudsopgave",
"Show blocks": "Blokken tonen",
"Show invisible characters": "Onzichtbare karakters tonen",
"Words: {0}": "Woorden: {0}",
"Insert": "Invoegen",
"File": "Bestand",
"Edit": "Bewerken",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich Text Area. Druk ALT-F9 voor het menu. Druk ALT-F10 voor de toolbar. Druk ALT-0 voor help.",
"Tools": "Gereedschap",
"View": "Beeld",
"Table": "Tabel",
"Format": "Opmaak"
});

==> roundcubemail-1.3.3-1-any.pkg.tar.xz: usr/share/webapps/roundcubemail/program/js/tinymce/langs/nl.js <==
tinymce.addI18n('nl',{
"Redo": "Opnieuw",
"Undo": "Ongedaan maken",
"Cut": "Knippen",
"Copy": "Kopi\u00ebren",
"Paste": "Plakken",
"Select all": "Alles selecteren",
"New document": "Nieuw document",
"Ok": "Ok\u00e9",
"Cancel": "Annuleren",
"Visual aids": "Hulpmiddelen",
"Bold": "Vet",
"Italic": "Cursief",
"Underline": "Onderstreept",
"Strikethrough": "Doorhalen",
"Superscript": "Superscript",
"Subscript": "Subscript",
"Clear formatting": "Opmaak verwijderen",
"Align left": "Links uitlijnen",
"Align center": "Centreren",
"Align right": "Rechts uitlijnen",
"Justify": "Uitlijnen",
"Bullet list": "Opsommingsteken",
"Numbered list": "Nummering",
"Decrease indent": "Inspringen verkleinen",
"Increase indent": "Inspringen vergroten",
"Close": "Sluiten",
"Formats": "Opmaak",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Uw browser ondersteunt geen toegang tot het clipboard. Gelieve ctrl+X\/C\/V sneltoetsen te gebruiken.",
"Headers": "Kopteksten",
"Header 1": "Kop 1",
"Header 2": "Kop 2",
"Header 3": "Kop 3",
"Header 4": "Kop 4",
"Header 5": "Kop 5",
"Header 6": "Kop 6",
"Headings": "Koppen",
"Heading 1": "Kop 1",
"Heading 2": "Kop 2",
"Heading 3": "Kop 3",
"Heading 4": "Kop 4",
"Heading 5": "Kop 5",
"Heading 6": "Kop 6",
"Div": "Div",
"Pre": "Pre",
"Code": "Code",
"Paragraph": "Paragraaf",
"Blockquote": "Quote",
"Inline": "Inlijn",
"Blocks": "Blok",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Plakken gebeurt nu als platte tekst. Tekst wordt nu ingevoegd zonder opmaak tot deze optie uitgeschakeld wordt.",
"Font Family": "Lettertype",
"Font Sizes": "Tekengrootte",
"Class": "Class",
"Browse for an image": "Zoek naar een afbeelding",
"OR": "OF",
"Drop an image here": "Plaats hier een afbeelding",
"Upload": "Uploaden",
"Block": "Blok",
"Align": "Uitlijnen",
"Default": "Standaard",
"Circle": "Cirkel",
"Disc": "Bolletje",
"Square": "Vierkant",
"Lower Alpha": "Kleine letters",
"Lower Greek": "Griekse letters",
"Lower Roman": "Romeinse cijfers klein",
"Upper Alpha": "Hoofdletters",
"Upper Roman": "Romeinse cijfers groot",
"Anchor": "Anker",
"Name": "Naam",
"Id": "ID",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "ID moet beginnen met een letter, gevolgd door letters, nummers, streepjes, punten, dubbele punten of underscores.",
"You have unsaved changes are you sure you want to navigate away?": "U hebt niet alles opgeslagen bent u zeker dat u de pagina wenst te verlaten?",
"Restore last draft": "Herstel het laatste concept",
"Special character": "Speciale karakters",
"Source code": "Broncode",
"Insert\/Edit code sample": "Broncode invoegen\/bewerken",
"Language": "Programmeertaal",
"Code sample": "Broncode voorbeeld",
"Color": "Kleur",
"R": "Rood",
"G": "Groen",
"B": "Blauw",
"Left to right": "Links naar rechts",
"Right to left": "Rechts naar links",
"Emoticons": "Emoticons",
"Document properties": "Document eigenschappen",
"Title": "Titel",
"Keywords": "Sleutelwoorden",
"Description": "Omschrijving",
"Robots": "Robots",
"Author": "Auteur",
"Encoding": "Codering",
"Fullscreen": "Volledig scherm",
"Action": "Actie",
"Shortcut": "Snelkoppeling",
"Help": "Help",
"Address": "Adres",
"Focus to menubar": "Menubalk selecteren",
"Focus to toolbar": "Werkbalk selecteren",
"Focus to element path": "Element pad selecteren",
"Focus to contextual toolbar": "Contextuele werkbalk selecteren",
"Insert link (if link plugin activated)": "Link invoegen (als link plug-in geactiveerd is)",
"Save (if save plugin activated)": "Opslaan (als opslaan plug-in ingeschakeld is)",
"Find (if searchreplace plugin activated)": "Zoeken (als zoeken\/vervangen plug-in ingeschakeld is)",
"Plugins installed ({0}):": "Plug-ins ge\u00efnstalleerd ({0}):",
"Premium plugins:": "Premium plug-ins:",
"Learn more...": "Leer meer...",
"You are using {0}": "Je gebruikt {0}",
"Plugins": "Plug-ins",
"Handy Shortcuts": "Handige snelkoppelingen",
"Horizontal line": "Horizontale lijn",
"Insert\/edit image": "Afbeelding invoegen\/bewerken",
"Image description": "Afbeelding omschrijving",
"Source": "Bron",
"Dimensions": "Afmetingen",
"Constrain proportions": "Verhoudingen behouden",
"General": "Algemeen",
"Advanced": "Geavanceerd",
"Style": "Stijl",
"Vertical space": "Verticale ruimte",
"Horizontal space": "Horizontale ruimte",
"Border": "Rand",
"Insert image": "Afbeelding invoegen",
"Image": "Afbeelding",
"Image list": "Afbeeldingenlijst",
"Rotate counterclockwise": "Linksom draaien",
"Rotate clockwise": "Rechtsom draaien",
"Flip vertically": "Verticaal spiegelen",
"Flip horizontally": "Horizontaal spiegelen",
"Edit image": "Bewerk afbeelding",
"Image options": "Afbeelding opties",
"Zoom in": "Inzoomen",
"Zoom out": "Uitzoomen",
"Crop": "Uitsnijden",
"Resize": "Formaat aanpassen",
"Orientation": "Orientatie",
"Brightness": "Helderheid",
"Sharpen": "Scherpte",
"Contrast": "Contrast",
"Color levels": "Kleurniveau's",
"Gamma": "Gamma",
"Invert": "Omkeren",
"Apply": "Toepassen",
"Back": "Terug",
"Insert date\/time": "Voeg datum\/tijd in",
"Date\/time": "Datum\/tijd",
"Insert link": "Hyperlink invoegen",
"Insert\/edit link": "Hyperlink invoegen\/bewerken",
"Text to display": "Linktekst",
"Url": "Url",
"Target": "Doel",
"None": "Geen",
"New window": "Nieuw venster",
"Remove link": "Link verwijderen",
"Anchors": "Anker",
"Link": "Link",
"Paste or type a link": "Plak of typ een link",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "De ingegeven URL lijkt op een e-mailadres. Wil je er \"mailto:\" aan toevoegen?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "De ingegeven URL verwijst naar een extern adres. Wil je er \"http:\/\/\" aan toevoegen?",
"Link list": "Linklijst",
"Insert video": "Video invoegen",
"Insert\/edit video": "Video invoegen\/bewerken",
"Insert\/edit media": "Media invoegen\/bewerken",
"Alternative source": "Alternatieve bron",
"Poster": "Poster",
"Paste your embed code below:": "Plak u in te sluiten code hieronder:",
"Embed": "Insluiten",
"Media": "Media",
"Nonbreaking space": "Vaste spatie invoegen",
"Page break": "Pagina einde",
"Paste as text": "Plakken als tekst",
"Preview": "Voorbeeld",
"Print": "Print",
"Save": "Opslaan",
"Find": "Zoeken",
"Replace with": "Vervangen door",
"Replace": "Vervangen",
"Replace all": "Alles vervangen",
"Prev": "Vorige",
"Next": "Volgende",
"Find and replace": "Zoek en vervang",
"Could not find the specified string.": "Geen resultaten gevonden",
"Match case": "Identieke hoofd\/kleine letters",
"Whole words": "Alleen hele woorden",
"Spellcheck": "Spellingscontrole",
"Ignore": "Negeren",
"Ignore all": "Alles negeren",
"Finish": "Einde",
"Add to Dictionary": "Toevoegen aan woordenlijst",
"Insert table": "Tabel invoegen",
"Table properties": "Tabel eigenschappen",
"Delete table": "Verwijder tabel",
"Cell": "Cel",
"Row": "Rij",
"Column": "Kolom",
"Cell properties": "Cel eigenschappen",
"Merge cells": "Cellen samenvoegen",
"Split cell": "Cel splitsen",
"Insert row before": "Voeg rij boven toe",
"Insert row after": "Voeg rij onder toe",
"Delete row": "Verwijder rij",
"Row properties": "Rij eigenschappen",
"Cut row": "Knip rij",
"Copy row": "Kopieer rij",
"Paste row before": "Plak rij boven",
"Paste row after": "Plak rij onder",
"Insert column before": "Voeg kolom in voor",
"Insert column after": "Voeg kolom in na",
"Delete column": "Verwijder kolom",
"Cols": "Kolommen",
"Rows": "Rijen",
"Width": "Breedte",
"Height": "Hoogte",
"Cell spacing": "Celruimte",
"Cell padding": "Ruimte binnen cel",
"Caption": "Onderschrift",
"Left": "Links",
"Center": "Midden",
"Right": "Rechts",
"Cell type": "Celtype",
"Scope": "Bereik",
"Alignment": "Uitlijning",
"H Align": "Links uitlijnen",
"V Align": "Boven uitlijnen",
"Top": "Bovenaan",
"Middle": "Centreren",
"Bottom": "Onderaan",
"Header cell": "Kopcel",
"Row group": "Rijgroep",
"Column group": "Kolomgroep",
"Row type": "Rijtype",
"Header": "Koptekst",
"Body": "Body",
"Footer": "Voettekst",
"Border color": "Randkleur",
"Insert template": "Sjabloon invoegen",
"Templates": "Sjablonen",
"Template": "Sjabloon",
"Text color": "Tekstkleur",
"Background color": "Achtergrondkleur",
"Custom...": "Eigen...",
"Custom color": "Eigen kleur",
"No color": "Geen kleur",
"Table of Contents": "Inhoudsopgave",
"Show blocks": "Blokken tonen",
"Show invisible characters": "Onzichtbare karakters tonen",
"Words: {0}": "Woorden: {0}",
"{0} words": "{0} woorden",
"File": "Bestand",
"Edit": "Bewerken",
"Insert": "Invoegen",
"View": "Beeld",
"Format": "Opmaak",
"Table": "Tabel",
"Tools": "Gereedschap",
"Powered by {0}": "Gemaakt door {0}",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich Text Area. Druk ALT-F9 voor het menu. Druk ALT-F10 voor de toolbar. Druk ALT-0 voor help."
});
